<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Selecte Course</title>
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@400;500&display=swap" rel="stylesheet">
    <!-- Include Select2 CSS library -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <style>
        body {
            font-family: 'Roboto', sans-serif;
            background-color: #f4f7f9;
            color: #333;
            margin: 0;
            padding: 0;
            display: flex;
            justify-content: center;
            align-items: center;
            min-height: 100vh;
            box-sizing: border-box;
        }

        .container {
            width: 100%;
            max-width: 600px;
            padding: 20px;
            box-sizing: border-box;
        }

        .image-container {
            margin-bottom: 20px;
            text-align: center;
        }

        .image-container img {
            max-width: 150px;
            height: auto;
            border-radius: 50%;
            border: 2px solid #003f5c;
        }

        .form-container {
            background: #ffffff;
            border-radius: 8px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
            padding: 20px;
            box-sizing: border-box;
            overflow: hidden;
        }

        .form-container label {
            display: block;
            margin-bottom: 10px;
            font-weight: 500;
            color: #003f5c;
        }

        .custom-select {
            width: 100%;
            padding: 10px;
            border: 1px solid #7aab7f;
            border-radius: 4px;
            font-size: 16px;
            color: #333;
            background-color: #ffffff;
            box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
            outline: none;
            box-sizing: border-box;
            max-width: 100%;
        }

        .custom-select:focus {
            border-color: #003f5c;
            box-shadow: 0 0 5px rgba(0, 63, 92, 0.3);
        }

        .custom-select option {
            padding: 10px;
        }

        .custom-select option:first-child {
            color: #aaa;
        }

        .price-field {
            font-size: 18px;
            color: #003f5c;
            margin: 15px 0;
            font-weight: bold;
            display: flex;
            align-items: center;
            justify-content: space-between;
        }

        .price-value {
            font-size: 24px;
            color: #e74c3c;
            /* Color for the price value */
            background-color: #f9f9f9;
            padding: 10px;
            border-radius: 4px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        }

        .submit-button {
            display: inline-block;
            background-color: #003f5c;
            color: #ffffff;
            padding: 10px 20px;
            border: none;
            border-radius: 4px;
            font-size: 16px;
            cursor: pointer;
            text-align: center;
            margin-top: 20px;
        }

        .submit-button:hover {
            background-color: #002a3a;
        }

        @media (max-width: 767px) {
            .custom-select {
                font-size: 14px;
                padding: 8px;
            }
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="image-container">
            <img src="img/homeImg.png" alt="University Logo" />
        </div>

        <div class="form-container">
            <form action="{{ route('student.register') }}" method="POST">
                @csrf
                <label for="course">Please select a course:</label>
                <select required class="custom-select" id="course" name="course" required>
                    <option selected disabled value="">Select a course</option>
                    @foreach ($course as $course)
                        <option value="{{ $course->id }}" data-price="{{ $course->courseCost }}">
                            {{ $course->courseName }}</option>
                    @endforeach
                </select>

                <div class="price-field">
                    <span>Price:</span>
                    <span id="price" class="price-value">0 JOD</span>
                </div>

                <button type="submit" class="submit-button">Next</button>
            </form>
        </div>
    </div>

    <!-- Include jQuery library -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <!-- Include Select2 JS library -->
    <script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
    <script>
        $(document).ready(function() {
            $('#course').select2({
                placeholder: "Select a course",
                width: 'resolve'
            }).on('change', function() {
                var selectedOption = $(this).find('option:selected');
                var price = selectedOption.data('price');
                $('#price').text(price + " " + 'JOD');
            });
        });
    </script>
</body>

</html>
